@@ -19,7 +19,7 @@
 #include "ExecutableFormat.h"
 #include "ELF.h"
 
-ExecutableFormat::ExecutableFormat(const u8 *image, Size size)
+ExecutableFormat::ExecutableFormat(const u8 *image, const Size size)
     : m_image(image)
     , m_size(size)
 {
@@ -30,7 +30,7 @@ ExecutableFormat::~ExecutableFormat()
 }
 
 ExecutableFormat::Result ExecutableFormat::find(const u8 *image,
-                                                Size size,
+                                                const Size size,
                                                 ExecutableFormat **fmt)
 {
     return ELF::detect(image, size, fmt);
