@@ -17,8 +17,9 @@
 
 #include "Device.h"
 
-Device::Device(FileSystem::FileType type)
-    : File(type)
+Device::Device(const u32 inode,
+               const FileSystem::FileType type)
+    : File(inode, type)
 {
 }
 
@@ -31,12 +32,12 @@ const String & Device::getIdentifier() const
     return m_identifier;
 }
 
-FileSystem::Error Device::initialize()
+FileSystem::Result Device::initialize()
 {
     return FileSystem::Success;
 }
 
-FileSystem::Error Device::interrupt(Size vector)
+FileSystem::Result Device::interrupt(const Size vector)
 {
     return FileSystem::Success;
 }
