@@ -15,21 +15,43 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <FreeNOS/User.h>
+#include <Log.h>
+#include <String.h>
 #include "NetworkQueue.h"
 
-NetworkQueue::NetworkQueue(Size packetSize, Size headerSize, Size queueSize)
+NetworkQueue::NetworkQueue(const Size packetSize,
+                           const Size queueSize)
 {
     assert(queueSize <= MaxPackets);
 
-    m_packetSize   = packetSize;
-    m_packetHeader = headerSize;
+    m_payloadRange.virt = ZERO;
+    m_payloadRange.phys = ZERO;
+    m_payloadRange.size = PayloadBufferSize * queueSize;
+    m_payloadRange.access = Memory::User | Memory::Readable | Memory::Writable;
 
-    for (Size i = 0; i < queueSize; i++)
+    // Ensure size is page aligned
+    if (m_payloadRange.size % PAGESIZE)
     {
-        Packet *packet = new Packet;
-        packet->size = m_packetHeader;
-        packet->data = new u8[packetSize];
-        m_free.insertAt(i, packet);
+        m_payloadRange.size += PAGESIZE - (m_payloadRange.size % PAGESIZE);
+    }
+
+    // Allocate memory pages for the payload
+    const API::Result result = VMCtl(SELF, MapContiguous, &m_payloadRange);
+    if (result != API::Success)
+    {
+        ERROR("failed to allocate payload buffer: result = " << (int) result);
+    }
+    else
+    {
+        // Allocate packet objects
+        for (Size i = 0; i < queueSize; i++)
+        {
+            Packet *packet = new Packet;
+            packet->size = 0;
+            packet->data = (u8 *) (m_payloadRange.virt + (i * PayloadBufferSize));
+            m_free.insertAt(i, packet);
+        }
     }
 }
 
@@ -40,15 +62,11 @@ NetworkQueue::~NetworkQueue()
         Packet *p = m_free.get(i);
         if (p)
         {
-            delete p->data;
             delete p;
         }
     }
-}
 
-void NetworkQueue::setHeaderSize(Size size)
-{
-    m_packetHeader = size;
+    VMCtl(SELF, Release, &m_payloadRange);
 }
 
 NetworkQueue::Packet * NetworkQueue::get()
@@ -58,7 +76,7 @@ NetworkQueue::Packet * NetworkQueue::get()
         Packet *p = m_free.get(i);
         if (p)
         {
-            p->size = m_packetHeader;
+            p->size = 0;
             m_free.remove(i);
             return p;
         }
@@ -68,7 +86,7 @@ NetworkQueue::Packet * NetworkQueue::get()
 
 void NetworkQueue::release(NetworkQueue::Packet *packet)
 {
-    packet->size = m_packetHeader;
+    packet->size = 0;
     m_free.insert(packet);
 }
 
@@ -90,3 +108,31 @@ NetworkQueue::Packet * NetworkQueue::pop()
     }
     return ZERO;
 }
+
+bool NetworkQueue::hasData() const
+{
+    return m_data.count() > 0;
+}
+
+Log & operator << (Log &log, const NetworkQueue::Packet & pkt)
+{
+    String s;
+
+    for (Size i = 0; i < pkt.size; i++)
+    {
+        if ((i % 16) == 0)
+            s << "\r\n";
+
+        const uint val = pkt.data[i];
+        s << Number::Hex << val;
+
+        if (val >= 0x10)
+            s << " ";
+        else
+            s << "  ";
+    }
+    s << "\r\n";
+
+    log.append(*s);
+    return log;
+}
