@@ -16,41 +16,23 @@
  */
 
 #include <FileSystemClient.h>
-#include <FileDescriptor.h>
 #include "errno.h"
 #include "unistd.h"
 
 ssize_t write(int fildes, const void *buf, size_t nbyte)
 {
-    FileDescriptor *files = getFiles();
+    // Write the file.
+    const FileSystemClient filesystem;
+    const FileSystem::Result result = filesystem.writeFile(fildes,
+                                                          (const char *)buf,
+                                                          &nbyte);
 
-    if (fildes >= FILE_DESCRIPTOR_MAX || fildes < 0)
-    {
-        errno = ERANGE;
-        return -1;
-    }
-
-    // Do we have this file descriptor?
-    if (!files[fildes].open)
+    // Did the write succeed?
+    if (result != FileSystem::Success)
     {
         errno = ENOENT;
         return -1;
     }
 
-    // Write the file.
-    const FileSystemClient filesystem;
-    const FileSystem::Result result = filesystem.writeFile(files[fildes].path,
-                                                          (const char *)buf,
-                                                         &nbyte,
-                                                          files[fildes].position);
-
-    // Did the write succeed?
-    if (result != FileSystem::Success)
-    {
-        errno = EIO;
-        return -1;
-    }
-
-    files[fildes].position += nbyte;
     return nbyte;
 }
