@@ -19,7 +19,6 @@
 #define __FILESYSTEM_LINN_FILESYSTEM_H
 
 #include <FileSystemServer.h>
-#include <FileSystemPath.h>
 #include <FileSystemMessage.h>
 #include <Storage.h>
 #include <Types.h>
@@ -66,6 +65,8 @@
  * static in size, i.e. 64-bytes. Those changes make it easier to program
  * the FileSystem implementation, thus easier to understand and learn from.
  *
+ * @todo Currently the LinnFileSystem is read-only and does not support writing.
+ *
  * @see FileSystemServer
  * @see Ext2FileSystem
  */
@@ -144,12 +145,16 @@ class LinnFileSystem : public FileSystemServer
      *
      * @param inode LinnInode pointer.
      * @param blk Calculate the offset for this block.
+     * @param numContiguous Number of contiguous blocks inside the same Inode
+     *                      starting at the given offset.
      *
      * @return Offset in bytes in storage.
      *
      * @see LinnInode
      */
-    u64 getOffset(LinnInode *inode, u32 blk);
+    u64 getOffsetRange(const LinnInode *inode,
+                       const u32 blk,
+                       Size & numContiguous);
 
   private:
 
