@@ -15,13 +15,14 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <FreeNOS/System.h>
+#include <FreeNOS/User.h>
 #include <KernelLog.h>
 #include <stdlib.h>
 #include "TmpFileSystem.h"
 
 int main(int argc, char **argv)
 {
+    KernelLog log;
     SystemInformation info;
     const char *path = "/tmp";
 
@@ -29,9 +30,6 @@ int main(int argc, char **argv)
     if (info.coreId != 0)
         return EXIT_SUCCESS;
 
-    KernelLog log;
-    log.setMinimumLogLevel(Log::Notice);
-
     if (argc > 1)
         path = argv[1];
 
